@@ -15,8 +15,8 @@
 import urllib2
 import sys
 import os
-from os.path import join, dirname, isdir
-from email import parser
+from os.path import join, dirname, isdir, normpath
+from email import message_from_string
 
 import shutil
 import zc.recipe.egg
@@ -36,6 +36,7 @@ pygments_style = 'sphinx'
 html_style = 'default.css'
 html_static_path = ['%(staticDir)s']
 html_last_updated_fmt = '%%b %%d, %%Y'
+extensions = %(extensions)r
 """
 
 class ZopeOrgSetup(object):
@@ -58,11 +59,14 @@ class ZopeOrgSetup(object):
     def install(self):
         installed = []
         eggs, workingSet = self.egg.working_set()
+        if 'doc-eggs' in self.options:
+            eggs = self.options['doc-eggs'].split()
         docs = [workingSet.find(pkg_resources.Requirement.parse(spec))
                 for spec in eggs]
 
         # Create parts directory for configuration files.
-        installDir = join(self.buildout['buildout']['parts-directory'], self.name)
+        installDir = join(
+            self.buildout['buildout']['parts-directory'], self.name)
         if not isdir(installDir):
             os.mkdir(installDir)
 
@@ -106,19 +110,22 @@ class ZopeOrgSetup(object):
                 open(join(staticDir,'layout.html'), 'w').write(f.read())
                 installed.append(join(staticDir, 'layout.html'))
 
-            metadata = dict(parser.Parser().parsestr('\n'.join(doc._get_metadata('PKG-INFO'))).items())
+            metadata = dict(message_from_string('\n'.join(
+                doc._get_metadata('PKG-INFO'))).items())
 
             #create conf.py
             confPyPath = join(partDir, 'conf.py')
             confPy = open(confPyPath, 'w')
-            confPy.write(confPyTemplate % dict(project=metadata.get('Name', doc.project_name),
-                                               copyright=metadata.get('Author', 'Zope Community'),
-                                               version=metadata.get('Version', doc.version),
-                                               release=metadata.get('Version', doc.version),
-                                               staticDir=staticDir,
-                                               templatesDir=templatesDir,
-                                               indexDoc=self.options.get('index-doc','index')
-                                               ))
+            confPy.write(confPyTemplate % dict(
+                project=metadata.get('Name', doc.project_name),
+                copyright=metadata.get('Author', 'Zope Community'),
+                version=metadata.get('Version', doc.version),
+                release=metadata.get('Version', doc.version),
+                staticDir=staticDir,
+                templatesDir=templatesDir,
+                indexDoc=self.options.get('index-doc','index'),
+                extensions=self.options.get('extensions','').split()
+                ))
             confPy.close()
             installed.append(confPyPath)
 
@@ -127,12 +134,16 @@ class ZopeOrgSetup(object):
             if not isdir(buildDir):
                 os.mkdir(buildDir)
 
-            srcDir = join(doc.location,
-                          srcDirs.get(doc.project_name,
-                                      self.options.get('src-dir',
-                                                       doc.project_name.replace('.','/'))))
+            buildDir = os.path.join(buildDir, doc.project_name)
+            if not isdir(buildDir):
+                os.mkdir(buildDir)
 
-            projectsData[doc.project_name] = ['-q','-c',partDir,
+            srcDir = join(doc.location, srcDirs.get(doc.project_name,
+                self.options.get('src-dir', doc.project_name.replace('.','/'))))
+            # fix bad path on windows (e.g. //foo\bar)
+            srcDir = normpath(srcDir)
+
+            projectsData[doc.project_name] = ['-q','-c', partDir,
                                               srcDir, buildDir]
 
         installed.extend(zc.buildout.easy_install.scripts(
